RFC2307UserGroupSchemaExtensions DEFINITIONS ::=
BEGIN

-- An integer uniquely identifying a user in an administrative domain
"uidNumber" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID                SYN_INTEGER,
	Flags                   { DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 0 } 
}

-- An integer uniquely identifying a group in an administrative domain
"gidNumber" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID                SYN_INTEGER,
	Flags                   { DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 1 }        
}

-- The GECOS field; the common name
"gecos" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID                SYN_CI_STRING,
	Flags                   { DS_STRING_ATTR, DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 2 } 
}

-- The absolute path to the home directory
"homeDirectory" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID                SYN_CE_STRING,
	Flags                   { DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 3 } 
}

-- The path to the login shell
"loginShell" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID                SYN_CE_STRING,
	Flags                   { DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 4 } 
}


"shadowLastChange" ATTRIBUTE ::=
{
	Operation 		ADD,
	SyntaxID		SYN_INTEGER,
	Flags			{ DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 5 } 
}

"shadowMin" ATTRIBUTE ::=
{
	Operation 		ADD,
	SyntaxID		SYN_INTEGER,
	Flags			{ DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 6 } 
}

"shadowMax" ATTRIBUTE ::=
{
	Operation 		ADD,
	SyntaxID		SYN_INTEGER,
	Flags			{ DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 7 } 
}

"shadowWarning" ATTRIBUTE ::=
{
	Operation 		ADD,
	SyntaxID		SYN_INTEGER,
	Flags			{ DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 8 } 
}

"shadowInactive" ATTRIBUTE ::=
{
	Operation 		ADD,
	SyntaxID		SYN_INTEGER,
	Flags			{ DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 9 } 
}

"shadowExpire" ATTRIBUTE ::=
{
	Operation 		ADD,
	SyntaxID		SYN_INTEGER,
	Flags			{ DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 10 } 
}

"shadowFlag" ATTRIBUTE ::=
{
	Operation 		ADD,
	SyntaxID		SYN_INTEGER,
	Flags			{ DS_SINGLE_VALUED_ATTR },
	ASN1ObjID { 1 3 6 1 1 1 1 11 } 
}

-- The uids of the users which belong to the group
"memberUid" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID                SYN_CE_STRING,
	ASN1ObjID { 1 3 6 1 1 1 1 12 } 
}

-- Abstraction of an account with POSIX attributes
"posixAccount" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_AUXILIARY_CLASS},
	SubClassOf		{"TOP"},
	MustContain		{	"CN" },
	MustContain		{	"uniqueID" },
	MustContain		{	"uidNumber" },
	MustContain		{	"gidNumber" },
	MustContain		{	"homeDirectory"	},
	MayContain		{	"loginShell" },
	MayContain		{	"gecos" },
	MayContain		{	"description"	},
	ASN1ObjID { 1 3 6 1 1 1 2 0 } 
}

"shadowAccount" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_AUXILIARY_CLASS},
	SubClassOf		{"TOP"},
	MustContain		{	"uniqueID"	},
	MayContain		{	"shadowLastChange" },
	MayContain		{	"shadowMin" },
	MayContain		{	"shadowMax" },
	MayContain		{	"shadowWarning"},
	MayContain		{	"shadowInactive" },
	MayContain		{	"shadowExpire" },
	MayContain		{	"shadowFlag" },
	MayContain		{	"description" },
	ASN1ObjID { 1 3 6 1 1 1 2 1 } 
}

-- Abstraction of a group of accounts
"posixGroup" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_AUXILIARY_CLASS},
	SubClassOf		{"TOP"}, 
	MustContain		{	"cn" },
	MustContain		{	"gidNumber"	},
	MayContain		{	"memberUid" },
	MayContain		{	"description"},
	ASN1ObjID { 1 3 6 1 1 1 2 2 } 
}

END



